/*
 * @Author: ch
 * @Date: 2022-04-25 14:39:19
 * @LastEditors: ch
 * @LastEditTime: 2022-05-17 18:14:57
 * @Description: file content
 */
import store from "../store";
import {createUUID, formatDate} from '@/common/utils';
let sessionListFlag = false;
const sessionList = (ctx) => {
	sessionListFlag = true;
	// 来新消息先查会话列表是否一存在，存在则加消息数。不存在则向会话列表加一个会话框
	ctx.sessionVOS.forEach(item => {
		if (item.lastMessage) {
			item.lastMessage.createTimeStamp = formatDate(item.lastMessage.createTimeStamp, 'mm-dd hh:ii')
			item.lastMessage.payload = JSON.parse(item.lastMessage.payload || {});
		}
		let historyData = store.state.sessionData;
		let hisIndex = historyData.findIndex(i => i.id === item.id);
		if(hisIndex >= 0){
			historyData[hisIndex].lastMessage = item.lastMessage;
			historyData[hisIndex].unreadCount++;
			store.commit('SET_SESSION_DATA', historyData);
		}else{
			item.messageList = [];
			store.commit('SET_SESSION_DATA',[...historyData, item]);
		}
	});
	// 消息总数
	store.commit('SET_SESSION_MSG_COUNT', ctx.totalUnreadCount);
}
const historyMsg = (ctx) => {
	if(!ctx.length){
		return false;
	}
	// ctx.reverse();
	let newData = store.state.sessionData;
	const hisIdx = newData.findIndex(i => i.id === ctx[0].sessionId);
	ctx.forEach(item => {
		item.createTimeStamp = formatDate(item.createTimeStamp, 'mm-dd hh:ii');
		item.payload = JSON.parse(item.payload)
	})
	// newData[hisIdx].messageList = ctx.concat(newData[hisIdx].messageList);
	newData[hisIdx].messageList = newData[hisIdx].messageList.concat(ctx);
	store.commit('SET_SESSION_DATA', newData);
}
/**
 * 收到某个会话的信息
 * @param {*} ctx 
 */
const sessionMsg = (ctx)=>{
	// 没接到会话列表时接到的消息不做处理
	if(!sessionListFlag){
		return
	}
	ctx.payload = JSON.parse(ctx.payload || {});
	ctx.createTimeStamp = formatDate(ctx.createTimeStamp || new Date(), 'mm-dd hh:ii')
	let historyData = store.state.sessionData;
	const hisIndex = historyData.findIndex(i => i.id === ctx.sessionId);
	// 不在当前会话框则全局消息加1
	if(ctx.sessionId !== store.state.sessionMsgId){
		store.commit('SET_SESSION_MSG_COUNT', store.state.sessionMsgCount + 1);
	}
	if(hisIndex >= 0){
		// 存在会话往现有会话增加一条消息
		const curHisData = historyData[hisIndex];
		// curHisData.messageList = [ ctx, ...(curHisData.messageList || [])]
		curHisData.messageList.push(ctx); //= [ ctx, ...(curHisData.messageList || [])]
		// 不在当前会话框则会话框消息加1
		if(ctx.sessionId !== store.state.sessionMsgId){
			curHisData.unreadCount++;
		}
		store.commit('SET_SESSION_DATA', historyData);
	}else{
		// 会话列表不存在，则创建一个会话
		store.commit('SET_SESSION_DATA',[...historyData, {
			fromAvatar : ctx.fromAvatar,
			fromId : ctx.fromId,
			fromNickname : ctx.fromNickname,
			id : ctx.id,
			lastMessage : ctx,
			messageList : [ctx],
			unreadCount : 1
		}]);
	}
	
}
// 用户自己创建了一个会话
const createSessionMain = (ctx) => {
	let historyData = store.state.sessionData;
	const curHis = historyData.find(i => i.id === ctx.id);
	store.commit('SET_SESSION_MSG_ID', ctx.id);
	if (curHis) {
		return false;
	}
	
	store.commit('SET_SESSION_DATA',[...historyData, {
		...ctx,
		unreadCount : 0,
		messageList : []
	}]);
	
}
export let MsbWebSkt = null;
const token = 'eyJhbGciOiJSUzI1NiJ9.eyJleHAiOjQwNzA4ODAwMDAsImlkIjo5LCJ0aW1lIjoxNjUyNTAwMDUyNTgwfQ.VAMmJTU1FAcw-vD39E_7EHoDaEdKD3A53L-kdcF6Hj_ygs1urs7xfTNsE2Z_Tb5wXRkS_j-qm0pGnRgfD2EQebc8Pcd28-Rp2W8o-CmCw2_uZUZbfUGeFRZ_ihsFCCpsepU7uEkA9L--cI_u3jw9xdNqzkiXYAVeAXsJ2j570bk'
export const MsbWebSktInit = () => {
	return new Promise((resolve, reject) => {
		MsbWebSkt = uni.connectSocket({
			url : `wss://you-gateway.mashibing.com/ws?client=${store.state.token}&type=1`, // url是websocket连接ip
			// url : `wss://k8s-horse-gateway.mashibing.cn/ws?client=${store.state.token}&type=1`, // url是websocket连接ip
			// url : `ws://192.168.10.93:8090/ws?client=${token}&type=1`, // url是websocket连接ip
			fail: e => {
				reject(e)
			}
		});
		MsbWebSkt.onOpen(() => {
			MsbWebSkt.onMessage((res) => {
				const data = JSON.parse(res.data || {});
				if (data.code === 200) {
					const ctx = data.content;
					switch (data.traceType) {
						// 会话列表
						case 1:
							sessionList(ctx);
							break;
						// 历史消息
						case 2:
						case 23:
							historyMsg(ctx);
							break;
						// 创建会话
						case 21:
							createSessionMain(ctx);
							break;
						// 会话消息
						case 25:
						case 20:
						case 7:
							sessionMsg(ctx)
							break;
						default:
							break;
					}
				}
			})
			resolve();
		});
		MsbWebSkt.onClose(() => {
			console.log('断开。。。。。');
		})
	})
	
}


